==> openshift-model-operator-6.9.2-sources.jar: io/fabric8/openshift/api/model/operator/v1/IngressControllerSpecBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
public class IngressControllerSpecBuilder extends IngressControllerSpecFluent<IngressControllerSpecBuilder> implements VisitableBuilder<IngressControllerSpec,IngressControllerSpecBuilder>{
  public IngressControllerSpecBuilder() {
    this(new IngressControllerSpec());
  }
  
  public IngressControllerSpecBuilder(IngressControllerSpecFluent<?> fluent) {
    this(fluent, new IngressControllerSpec());
  }
  
  public IngressControllerSpecBuilder(IngressControllerSpecFluent<?> fluent,IngressControllerSpec instance) {
    this.fluent = fluent;
    fluent.copyInstance(instance);
  }
  
  public IngressControllerSpecBuilder(IngressControllerSpec instance) {
    this.fluent = this;
    this.copyInstance(instance);
  }
  IngressControllerSpecFluent<?> fluent;
  
  public IngressControllerSpec build() {
    IngressControllerSpec buildable = new IngressControllerSpec(fluent.buildClientTLS(),fluent.buildDefaultCertificate(),fluent.getDomain(),fluent.buildEndpointPublishingStrategy(),fluent.buildHttpCompression(),fluent.getHttpEmptyRequestsPolicy(),fluent.getHttpErrorCodePages(),fluent.buildHttpHeaders(),fluent.buildLogging(),fluent.buildNamespaceSelector(),fluent.buildNodePlacement(),fluent.getReplicas(),fluent.buildRouteAdmission(),fluent.buildRouteSelector(),fluent.getTlsSecurityProfile(),fluent.buildTuningOptions(),fluent.buildUnsupportedConfigOverrides());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  

}

==> openshift-model-operator-7.1.0-sources.jar: io/fabric8/openshift/api/model/operator/v1/IngressControllerSpecBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
public class IngressControllerSpecBuilder extends IngressControllerSpecFluent<IngressControllerSpecBuilder> implements VisitableBuilder<IngressControllerSpec,IngressControllerSpecBuilder>{
  public IngressControllerSpecBuilder() {
    this(new IngressControllerSpec());
  }
  
  public IngressControllerSpecBuilder(IngressControllerSpecFluent<?> fluent) {
    this(fluent, new IngressControllerSpec());
  }
  
  public IngressControllerSpecBuilder(IngressControllerSpecFluent<?> fluent,IngressControllerSpec instance) {
    this.fluent = fluent;
    fluent.copyInstance(instance);
  }
  
  public IngressControllerSpecBuilder(IngressControllerSpec instance) {
    this.fluent = this;
    this.copyInstance(instance);
  }
  IngressControllerSpecFluent<?> fluent;
  
  public IngressControllerSpec build() {
    IngressControllerSpec buildable = new IngressControllerSpec(fluent.buildClientTLS(),fluent.buildDefaultCertificate(),fluent.getDomain(),fluent.buildEndpointPublishingStrategy(),fluent.buildHttpCompression(),fluent.getHttpEmptyRequestsPolicy(),fluent.getHttpErrorCodePages(),fluent.buildHttpHeaders(),fluent.buildLogging(),fluent.buildNamespaceSelector(),fluent.buildNodePlacement(),fluent.getReplicas(),fluent.buildRouteAdmission(),fluent.buildRouteSelector(),fluent.getTlsSecurityProfile(),fluent.buildTuningOptions(),fluent.getUnsupportedConfigOverrides());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  

}
